<?xml version="1.0" encoding="iso-8859-1"?>

<!--
text.xsl

Copyright (c) 2001,2002 Florent Villard (warly@laposte.net)
Published under the GPL license.
-->

<xsl:stylesheet version="1.0"
	 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="iso-8859-1"/>
  <xsl:output doctype-public="-//W3C//DTD HTML 4.0//EN"/>
  <xsl:strip-space elements="*"/>

  <xsl:template match="/">
        <xsl:apply-templates select="vie"/>
  </xsl:template>

  <xsl:template name="newLine">
<xsl:text>

</xsl:text>
  </xsl:template>

  <xsl:template name="vie">

         <xsl:apply-templates select="header"/>
         <xsl:apply-templates select="body"/>
  </xsl:template>
  
  <xsl:template match="header">
<xsl:text>\documentclass[12pt,a4paper,french]{book}
\usepackage{acronym}
\usepackage[T1]{fontenc}
\usepackage{epsf}
\usepackage{babel}
\usepackage[dvips]{graphics}
\usepackage{graphicx}
%\usepackage{indentfirst}
\usepackage{fancyheadings}
\usepackage{verbatim}
\usepackage{vmargin}
\usepackage{ae}
\setpapersize{A4}
\setmarginsrb{138pt}{110pt}{138pt}{110pt}{20pt}{10pt}{20pt}{20pt}
%\initfloatingfigs

\begin{document}
        </xsl:text>
        <xsl:text>\title{</xsl:text>
        <xsl:value-of select="doctitle"/>
        <xsl:text>\\\ \\</xsl:text>
        <xsl:value-of select="booktitle"/>
        <xsl:text>}</xsl:text>

	<xsl:call-template name="newLine"/>

        <xsl:apply-templates select="author"/>
        
	<xsl:call-template name="newLine"/>

        <xsl:apply-templates select="date"/>

	<xsl:call-template name="newLine"/>
        <xsl:text>
\maketitle

\vspace*{8cm}
        </xsl:text>
        <xsl:apply-templates select="version"/>

	<xsl:call-template name="newLine"/>

	<xsl:apply-templates select="copyright"/>

	<xsl:call-template name="newLine"/>
        
  </xsl:template>

  <xsl:template match="author">
        <xsl:text>\author{</xsl:text>
	<xsl:value-of select="firstname"/>
	<xsl:text> (</xsl:text>
	<xsl:value-of select="surname"/>
	<xsl:text>) \textsc{</xsl:text>
	<xsl:value-of select="lastname"/>
        <xsl:text>}}</xsl:text>
  </xsl:template>

  <xsl:template match="date">
        <xsl:text>\date{</xsl:text>
	<xsl:value-of select="."/>
        <xsl:text>}</xsl:text>
  </xsl:template>

  <xsl:template match="copyright">
	<xsl:text>\begin{footnotesize}Copyright \copyright </xsl:text>
	<xsl:value-of select="year"/>
	<xsl:text>, </xsl:text>
        <xsl:value-of select="holder"/>
	<xsl:call-template name="newLine"/>
	<xsl:value-of select="license"/>
	<xsl:call-template name="newLine"/>
	<xsl:value-of select="licensetext"/>
        <xsl:text>\end{footnotesize}</xsl:text>
  </xsl:template>

  <xsl:template match="version">
	<xsl:text>\begin{footnotesize}Version: </xsl:text>
        <xsl:value-of select="."/>
        <xsl:text>\end{footnotesize}</xsl:text>
  </xsl:template>
 
  <xsl:template match="body">
        <xsl:text>
\strut\thispagestyle{empty}
\pagebreak
        </xsl:text>
	<xsl:apply-templates select="acknowledgments"/>
        <xsl:text>
\setcounter{page}{1}

\pagestyle{fancy}
\lhead[\thepage]{\leftmark}
\rhead[\rightmark]{\thepage}
\renewcommand{\chaptermark}[1]{\markboth{#1}{
	</xsl:text>
	<xsl:value-of select="/vie/header/booktitle"/>
        <xsl:text>
}}
\cfoot{{\footnotesize
        </xsl:text>
        <xsl:value-of select="/vie/header/doctitle"/>
        <xsl:text> - </xsl:text>
        <xsl:value-of select="/vie/header/version"/>
        <xsl:text>}}</xsl:text>

	<xsl:apply-templates select="preface"/>
        <xsl:text>
\vfill
\pagebreak
\strut\thispagestyle{empty}
         </xsl:text>
	<xsl:apply-templates select="(part|chapter|section|para|day|img)"/>
        <xsl:call-template name="newLine"/>
        <xsl:text>\tableofcontents
\listoffigures
\end{document}</xsl:text>
  </xsl:template>

  <xsl:template match="part">
    <xsl:call-template name="newLine"/>
	<xsl:text>\part*{</xsl:text>
	  <xsl:value-of select="title"/>
	  <xsl:text>\\</xsl:text>
       	  <xsl:value-of select="subtitle"/>
        <xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:text>\addcontentsline{toc}{part}{</xsl:text>
	<xsl:value-of select="title"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="subtitle"/>
	<xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:text>\chaptermark{</xsl:text>
	  <xsl:value-of select="title"/>
        <xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:text>\chapter*{}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|chapter|section|day|img)"/>
  </xsl:template>

  <xsl:template match="chapter">
    <xsl:call-template name="newLine"/>
        <xsl:text>\chapter*{</xsl:text>
       	  <xsl:value-of select="title"/>
	  <xsl:text>\\</xsl:text>
       	  <xsl:value-of select="subtitle"/>
       	<xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:text>\addcontentsline{toc}{chapter}{</xsl:text>
	<xsl:value-of select="title"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="subtitle"/>
	<xsl:text>}</xsl:text>
	<xsl:apply-templates select="(para|section|day|img)"/>
  </xsl:template>

  <xsl:template match="img">
    <xsl:call-template name="newLine"/>
    <xsl:text>\begin{figure}
\begin{center}
\includegraphics[scale=</xsl:text>
       	  <xsl:value-of select="scale"/>
       	<xsl:text>]{</xsl:text>
       	  <xsl:value-of select="src"/>
       	<xsl:text>.ps}
\caption[</xsl:text>
       	  <xsl:value-of select="index"/>
       	<xsl:text>]{</xsl:text>
       	  <xsl:value-of select="caption"/>
       	<xsl:text>}
\label{</xsl:text>
       	  <xsl:value-of select="label"/>
       	<xsl:text>}</xsl:text>
       	<xsl:text>
\end{center}
\end{figure}</xsl:text>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="day">
    <xsl:call-template name="newLine"/>
    <xsl:text>\section*{</xsl:text>
       	  <xsl:value-of select="."/>
       	<xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="acknowledgments">
    <xsl:call-template name="newLine"/>
        <xsl:text>\chapter*{</xsl:text>
       	  <xsl:text>Remerciements</xsl:text>
       	<xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="preface">
    <xsl:call-template name="newLine"/>
        <xsl:text>\chapter*{</xsl:text>
	<xsl:text>Prface</xsl:text>
       	<xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="section">
    <xsl:call-template name="newLine"/>
        <xsl:text>\section{</xsl:text>
	    <xsl:value-of select="title"/>
        <xsl:text>}</xsl:text>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|day|img)"/>
  </xsl:template>
   
  <xsl:template match="para">
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="newLine"/>
    <xsl:value-of select="."/>
  </xsl:template>

</xsl:stylesheet>
