<?xml version="1.0" encoding="iso-8859-1"?>

<!--
text.xsl

Copyright (c) 2001,2002 Florent Villard (warly@laposte.net)
Published under the GPL license.
-->

<xsl:stylesheet version="1.0"
	 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="iso-8859-1"/>
  <xsl:output doctype-public="-//W3C//DTD HTML 4.0//EN"/>
  <xsl:strip-space elements="*"/>

  <xsl:template match="/">
	  <xsl:apply-templates select="vie"/>
  </xsl:template>

  <xsl:template name="newLine">
<xsl:text>
</xsl:text>
  </xsl:template>
  
  <xsl:template name="nNewLine">
    <xsl:param name="n" select="0"/>
    <xsl:if test="$n &gt; 0">
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nNewLine">
      <xsl:with-param name="n" select="$n - 1" />
    </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="nSpace">
    <xsl:param name="n" select="0"/>
    <xsl:if test="$n &gt; 0">
    <xsl:text> </xsl:text>
    <xsl:call-template name="nSpace">
    <xsl:with-param name="n" select="$n - 1" />
    </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="nChar">
    <xsl:param name="n" select="0"/>
    <xsl:param name="char"/>
    <xsl:if test="$n &gt; 0">
      <xsl:value-of select="$char"/>
      <xsl:call-template name="nChar">
        <xsl:with-param name="n" select="$n - 1" />
        <xsl:with-param name="char"> 
          <xsl:value-of select="$char"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="center">
    <xsl:param name="text"/>
    <xsl:param name="width" select="80"/> 
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nSpace">
      <xsl:with-param name="n" select="($width - string-length($text)) div 2" />
    </xsl:call-template>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="newLine"/>
  </xsl:template>

 <xsl:template name="replace">
    <xsl:param name="text"/>
    <xsl:param name="char1"/>
    <xsl:param name="char2"/>
    <xsl:choose>
      <xsl:when test="contains($text,$char1)">
        <xsl:value-of select="substring-before($text,$char1)"/>
        <xsl:value-of select="$char2"/>
        <xsl:call-template name="replace">
          <xsl:with-param name="char1">
             <xsl:value-of select="$char1"/>
          </xsl:with-param>
          <xsl:with-param name="char2">
             <xsl:value-of select="$char2"/>
          </xsl:with-param>
          <xsl:with-param name="text" select="substring-after($text,$char1)"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

 <xsl:template name="justify" >
    <xsl:param name="text"  />
    <xsl:param name="width" select="80"/>
    <xsl:param name="pos"  select="0" /> 
    
    <xsl:call-template name="justifyText">
      <xsl:with-param name="width" select="$width"/>
      <xsl:with-param name="pos" select="0"/> 
      <xsl:with-param name="text">
         <xsl:call-template name="replace">
           <xsl:with-param name="text">
             <xsl:value-of select="$text"/>
           </xsl:with-param>
           <xsl:with-param name="char1">
             <xsl:text>&#xa;</xsl:text>
           </xsl:with-param>
           <xsl:with-param name="char2">
             <xsl:text> </xsl:text>
           </xsl:with-param>
         </xsl:call-template>     
       </xsl:with-param>
    </xsl:call-template>       
  </xsl:template>

  <xsl:template name="justifyText">
    <xsl:param name="text"  />
    <xsl:param name="width" select="80"/>
    <xsl:param name="pos"  select="0" /> 
   <xsl:if test="$pos=0">
    <xsl:call-template name="newLine"/>
   </xsl:if>
   <xsl:if test="string-length($text) > 0">
    <xsl:choose>
        <xsl:when test="contains($text,' ')">
            <xsl:variable name="word" select="substring-before($text,' ')"/>
               <xsl:value-of select="$word"/>
              <xsl:if test="(1 + $pos + string-length($word)) &gt; $width">
                  <xsl:call-template name="justifyText">
                    <xsl:with-param name="text" select="substring-after($text,' ')"/>
                    <xsl:with-param name="width" select="$width"/>
                    <xsl:with-param name="pos" select="0"/>
                  </xsl:call-template>
              </xsl:if>
              <xsl:if test="($pos + string-length($word)) &lt; $width">
                  <xsl:text> </xsl:text>
                  <xsl:call-template name="justifyText">
                    <xsl:with-param name="text" select="substring-after($text,' ')"/>
                    <xsl:with-param name="width" select="$width"/>
                    <xsl:with-param name="pos" select="$pos + string-length($word) + 1"/>
                  </xsl:call-template>
              </xsl:if>
        </xsl:when>
        <xsl:otherwise><xsl:value-of select="$text"/></xsl:otherwise>
    </xsl:choose>
   </xsl:if>
 </xsl:template>

  <xsl:template name="makeTitle">
    <xsl:param name="text"/>
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="newLine"/>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nChar">
      <xsl:with-param name="n" select="(string-length($text))" />
      <xsl:with-param name="char"> 
        <xsl:text>-</xsl:text>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="/vie">
	<xsl:apply-templates select="header"/>
	<xsl:call-template name="nNewLine"/>
	<xsl:apply-templates select="body"/>
  </xsl:template>

  <xsl:template match="header">
	<xsl:call-template name="nNewLine">
          <xsl:with-param name="n" select="5"/>
        </xsl:call-template>	

        <xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="doctitle"/>
           </xsl:with-param>
        </xsl:call-template>
	
	<xsl:call-template name="newLine"/>
        
	<xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="booktitle"/>
           </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>

	<xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:apply-templates select="author"/>
           </xsl:with-param>
        </xsl:call-template>
        
	<xsl:call-template name="newLine"/>

        <xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="date"/>
           </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>

	<xsl:call-template name="nNewLine">
          <xsl:with-param name="n" select="10"/>
        </xsl:call-template>
	
        <xsl:apply-templates select="version"/>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="copyright"/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="author">
	<xsl:value-of select="firstname"/>
	<xsl:text> (</xsl:text>
	<xsl:value-of select="surname"/>
	<xsl:text>) </xsl:text>
	<xsl:value-of select="lastname"/>
  </xsl:template>

  <xsl:template match="date">
	<xsl:call-template name="newLine"/>
	<xsl:value-of select="."/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="copyright">
	<xsl:call-template name="newLine"/>
	<xsl:text>Copyright </xsl:text>
	<xsl:value-of select="year"/>
	<xsl:text> </xsl:text>
        <xsl:value-of select="holder"/>
	<xsl:call-template name="newLine"/>
        <xsl:value-of select="license"/>
	<xsl:call-template name="newLine"/>
        <xsl:value-of select="licensetext"/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="version">
	<xsl:text>Version: </xsl:text><xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="body">
	<xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:apply-templates select="acknowledgments"/>
	<xsl:apply-templates select="prface"/>
	<xsl:apply-templates select="(part|chapter|section|para|day)"/>
  </xsl:template>

  <xsl:template match="part">
	<xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|chapter|section|day)"/>
  </xsl:template>

  <xsl:template match="day">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="."/>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
  </xsl:template>

 <xsl:template match="chapter">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|section|day)"/>
  </xsl:template>

 <xsl:template match="acknowledgments">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:text>Remerciements</xsl:text>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="preface">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:text>Preface</xsl:text>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="section">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|day)"/>
  </xsl:template>
   
  <xsl:template match="para">
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="justify">
      <xsl:with-param name="text">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="width" select="80"/>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
